import { useRef } from 'react';
import { useDripsyTheme } from './use-dripsy-theme';
import { css } from './css';
import { useBreakpointIndex } from './css/breakpoint-context';
import stableHash from 'stable-hash';
export function useSx() {
    const { theme } = useDripsyTheme();
    const breakpoint = useBreakpointIndex();
    const cache = useRef(new Map());
    return (sx, { themeKey } = {}) => {
        const themedStyle = css(sx, breakpoint)({
            theme,
            themeKey,
        });
        const hash = stableHash(themedStyle);
        if (!cache.current.has(hash)) {
            cache.current.set(hash, themedStyle);
        }
        return cache.current.get(hash);
    };
}
//# sourceMappingURL=use-sx.js.map